==> haskell-servant-server-0.17-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-server
version:              0.17
visibility:           public
id:                   servant-server-0.17-94t7trhgTIVBDOJyjVYySW
key:                  servant-server-0.17-94t7trhgTIVBDOJyjVYySW
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    A family of combinators for defining webservices APIs and serving them

description:
    A family of combinators for defining webservices APIs and serving them

    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.

    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.

    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  7b413eb4c2c070abad7e25ab498d740b
exposed:              True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.Handler Servant.Server.Internal.RouteResult
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Utils.StaticFiles

import-dirs:          /usr/lib/ghc-8.10.1/site-local/servant-server-0.17
library-dirs:         /usr/lib/ghc-8.10.1/site-local/servant-server-0.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/servant-server-0.17
hs-libraries:         HSservant-server-0.17-94t7trhgTIVBDOJyjVYySW
depends:
    base-4.14.0.0 base-compat-0.11.1-KZnxD44j0rC2RthL96Vmwl
    base64-bytestring-1.1.0.0-BUHOsOVhKeC5M6ZjmSxE5I
    bytestring-0.10.10.0 containers-0.6.2.1 exceptions-0.10.4
    filepath-1.4.2.1 http-api-data-0.4.1.1-D5iakJrYJ5mJmPLFFdxqNE
    http-media-0.8.0.0-5aRpLOqEjgnClrwJtGd0XD
    http-types-0.12.3-3aTIs7Loo89HU4044vXXZG
    monad-control-1.0.2.3-CSwxHoEhR3wLOgI9xoqEra mtl-2.2.2
    network-3.1.1.1-D3CIp0WkhfC51dOZjHWRWc
    network-uri-2.6.3.0-HuGcBg57qhu6ZoFTEXyfPG
    resourcet-1.2.4-D9lelWYYOwO39oUPVIVnqn
    servant-0.17-EI1tbCcjYuOGt9X9lKx4X2
    string-conversions-0.4.0.1-B7nbcmmSZDsLQwPoMWPWXw
    tagged-0.8.6-6GC8EUw1ctH7ZAzzvpqZ7j text-1.2.3.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-6dTWVQVkpndEzF8CB6LlYd
    wai-3.2.2.1-K94jftDFBiDLlXiDojfnI9
    wai-app-static-3.1.7.1-SLQUYkLIuyJBkxsWY9Dnn
    word8-0.1.3-2HAv1NwMSKOALyj2PF53yL

haddock-interfaces:
    /usr/share/doc/haskell-servant-server/html/servant-server.haddock

haddock-html:         /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-server-0.17-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-server
version:              0.17
visibility:           public
id:                   servant-server-0.17-1vGZrcS2d2VDlnRL9fwnjs
key:                  servant-server-0.17-1vGZrcS2d2VDlnRL9fwnjs
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    A family of combinators for defining webservices APIs and serving them

description:
    A family of combinators for defining webservices APIs and serving them

    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.

    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.

    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  198f06c8a68c51722ffacf27bc574004
exposed:              True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.Handler Servant.Server.Internal.RouteResult
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Utils.StaticFiles

import-dirs:          /usr/lib/ghc-8.10.1/site-local/servant-server-0.17
library-dirs:         /usr/lib/ghc-8.10.1/site-local/servant-server-0.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/servant-server-0.17
hs-libraries:         HSservant-server-0.17-1vGZrcS2d2VDlnRL9fwnjs
depends:
    base-4.14.0.0 base-compat-0.11.1-KZnxD44j0rC2RthL96Vmwl
    base64-bytestring-1.1.0.0-BUHOsOVhKeC5M6ZjmSxE5I
    bytestring-0.10.10.0 containers-0.6.2.1 exceptions-0.10.4
    filepath-1.4.2.1 http-api-data-0.4.1.1-DPZIDxg3L8VErKxvcqPwtV
    http-media-0.8.0.0-5aRpLOqEjgnClrwJtGd0XD
    http-types-0.12.3-1kde9KJAuu38Zmp5WnQ1fU
    monad-control-1.0.2.3-CSwxHoEhR3wLOgI9xoqEra mtl-2.2.2
    network-3.1.1.1-D3CIp0WkhfC51dOZjHWRWc
    network-uri-2.6.3.0-54TWgKKe6U922UUmUyUwcg
    resourcet-1.2.4.1-9xR8S81TBpB7QzWM5vUBSa
    servant-0.17-Kv0tCqPeRKyDbdsUW1HdSV
    string-conversions-0.4.0.1-B7nbcmmSZDsLQwPoMWPWXw
    tagged-0.8.6-6GC8EUw1ctH7ZAzzvpqZ7j text-1.2.3.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-6dTWVQVkpndEzF8CB6LlYd
    wai-3.2.2.1-3MZN0hsjN1f5dgCtoZeKBL
    wai-app-static-3.1.7.1-2VaAfe9myUHEt0ARV9ZxqU
    word8-0.1.3-2HAv1NwMSKOALyj2PF53yL

haddock-interfaces:
    /usr/share/doc/haskell-servant-server/html/servant-server.haddock

haddock-html:         /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
